==> apache-cxf-3.5.10-src.zip: apache-cxf-3.5.10-src/systests/jaxws/src/test/java/org/apache/cxf/systest/jaxws/schemavalidation/PersonServiceAnnotatedImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.jaxws.schemavalidation;

import javax.jws.WebService;

@WebService(endpointInterface = "org.apache.cxf.systest.jaxws.schemavalidation.PersonServiceAnnotated",
    serviceName = "PersonServiceAnnotated",
    targetNamespace = "http://org.apache.cxf/service/PersonServiceAnnotated")
public class PersonServiceAnnotatedImpl implements PersonServiceAnnotated {
    @Override
    public Person saveNoValidation(Person data) {
        return data;
    }

    @Override
    public Person saveInheritEndpoint(Person data) {
        return data;
    }

    @Override
    public Person saveValidateIn(Person data) {
        if ("InvalidResponse".equals(data.getFirstName())) {
            return new Person();
        }
        return data;
    }

    @Override
    public Person saveValidateOut(Person data) {
        return data;
    }
}

==> apache-cxf-4.1.3-src.zip: apache-cxf-4.1.3-src/systests/jaxws/src/test/java/org/apache/cxf/systest/jaxws/schemavalidation/PersonServiceAnnotatedImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.jaxws.schemavalidation;

import jakarta.jws.WebService;

@WebService(endpointInterface = "org.apache.cxf.systest.jaxws.schemavalidation.PersonServiceAnnotated",
    serviceName = "PersonServiceAnnotated",
    targetNamespace = "http://org.apache.cxf/service/PersonServiceAnnotated")
public class PersonServiceAnnotatedImpl implements PersonServiceAnnotated {
    @Override
    public Person saveNoValidation(Person data) {
        return data;
    }

    @Override
    public Person saveInheritEndpoint(Person data) {
        return data;
    }

    @Override
    public Person saveValidateIn(Person data) {
        if ("InvalidResponse".equals(data.getFirstName())) {
            return new Person();
        }
        return data;
    }

    @Override
    public Person saveValidateOut(Person data) {
        return data;
    }
}
